Stan Math Library: stan/math/rev/scal/fun/if_else.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
if_else.hpp File Reference
`#include <stan/math/rev/core.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
var | stan::math::if_else (bool c, const var &y_true, const var &y_false)
| If the specified condition is true, return the first variable, otherwise return the second variable. More...
var | stan::math::if_else (bool c, double y_true, const var &y_false)
| If the specified condition is true, return a new variable constructed from the first scalar, otherwise return the second variable. More...
var | stan::math::if_else (bool c, const var &y_true, const double y_false)
| If the specified condition is true, return the first variable, otherwise return a new variable constructed from the second scalar. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.